@@ -1,29 +1,24 @@
 #!/usr/bin/env python
-
-"""A lightweight wrapper around PostgreSQL.
-Ported from http://github.com/bdarnell/torndb
-"""
-
 import itertools
 import logging
 import psycopg2
 import re
 
-version = "0.0.3"
-version_info = (0, 0, 3)
+__version__ = VERSION = version = '0.0.4'
+version_info = (0, 0, 4)
 
 
 class Connection(object):
     def __init__(self, host_or_url, database=None, user=None, password=None, port=5432):
         self.logging = False
         if host_or_url.startswith('postgres://'):
-            args = re.search('postgres://(?P<user>[\w\-]+):(?P<password>[\w\-]*)@(?P<host>.*):(?P<port>\d+)/(?P<database>[\w\-]+)', host_or_url).groupdict()
+            args = re.search('postgres://(?P<user>[\w\-]+):?(?P<password>[\w\-]*)@(?P<host>.*):(?P<port>\d+)/(?P<database>[\w\-]+)', host_or_url).groupdict()
             self.host = args.get('host')
             self.database = args.get('database')
         else:
             self.host = host_or_url
             self.database = database
-            args = dict(host=host_or_url, database=database, port=port, 
+            args = dict(host=host_or_url, database=database, port=int(port), 
                         user=user, password=password)
 
         self._db = None
